/**
 * ab_leaflet_maps package for Concrete5
 * Copyright Copyright 2018-2019, Alex Borisov
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @package Concrete\Package\ab_leaflet_maps
 */

$(document).ready(function(e) {
    if(CCM_EDIT_MODE){
        return;
    }
    
    $.each($('.ab-leaflet-map[data-jq]'), function(index, element) {
        var jq_data = $.parseJSON($(element).attr('data-jq'));
        InitLeafletMap(element, jq_data);
    });

    function InitLeafletMap(element, jq_data) {
        var Leaflet = L.noConflict();
        (function(Leaflet){
            var myLeafletBalloon = '<div class="my-balloon">';
            if (jq_data.show_picture) {
                myLeafletBalloon += '<div class="left">';
                myLeafletBalloon += '<img src="' + jq_data.picture + '" />';
                myLeafletBalloon += '</div>';
            }
            myLeafletBalloon += '<div class="right">'; 
            myLeafletBalloon += '<h3>' + jq_data.name + '</h3>';
            myLeafletBalloon += jq_data.show_address ? ('<strong>' + jq_data.t_address + '</strong> ' + jq_data.address + '<br />') : '';
            myLeafletBalloon += jq_data.show_tel ? ('<strong>' + jq_data.t_tel + '</strong> ' + jq_data.tel + '<br />') : '';
            myLeafletBalloon += jq_data.show_email ? ('<strong>' + jq_data.t_email + '</strong> <a href="mailto:' + jq_data.email + '">' + jq_data.email + '</a>') : '';
            myLeafletBalloon += '</div>';
            myLeafletBalloon += '</div>';
                
            var myLeafletHint = '<div class="my-hint">';
            myLeafletHint += '<b>' + jq_data.name + '</b><br />';
            myLeafletHint += jq_data.address + '<br />';
            myLeafletHint += jq_data.tel + '<br />';
            myLeafletHint += jq_data.email;
            myLeafletHint += '</div>';
                
            var myLeafletMap, myLeafletPopUp, myLeafletPlacemark;

            var myLeafletStreets = Leaflet.tileLayer.Unwired({
                key: jq_data.api_key, 
                scheme: "streets",
            });
            
            myLeafletMap = Leaflet.map(element, {
                center: [jq_data.latitude, jq_data.longitude],
                zoom: jq_data.zoom ? jq_data.zoom : 16,
                scrollWheelZoom : jq_data.lock_wheel,
                layers: [myLeafletStreets],
            });
            Leaflet.control.scale().addTo(myLeafletMap);
            
            myLeafletPopUp = Leaflet.popup();
            myLeafletPopUp.setLatLng([jq_data.latitude, jq_data.longitude]);
            myLeafletPopUp.setContent(myLeafletBalloon);
            
            myLeafletPlacemark = Leaflet.marker([jq_data.latitude, jq_data.longitude]).addTo(myLeafletMap);
            myLeafletPlacemark.bindPopup(myLeafletPopUp, {
                maxWidth: 'auto',
            });
            myLeafletPlacemark.bindTooltip(myLeafletHint, {
                className: 'ab-leaflet-maps-hint',
            });
        })(L)
    };
});
